Craddock 2012


Notes
-----
Collection of regions of interest (ROI) that have been generated from applying
spatially constrained clustering on resting-state data.

Several clustering statistics are used to compare methodological trade-offs
as well as determine an adequate number of clusters. The proposed functional
and random parcellations perform equivalently for most of the metrics evaluated.
The online release also contains the scripts to derive these ROI atlases
by using spatially constrained Ncut spectral clustering.


Content
-------
    :'random': result of random clustering for comparison
    :'scorr_2level': parcellation results when emphasizing spatial homogeneity
    :'scorr_mean': group-mean parcellation results when emphasizing spatial homogeneity
    :'tcorr_2level': parcellation results when emphasizing temporal homogeneity
    :'tcorr_mean': group-mean parcellation results when emphasizing temporal homogeneity


References
----------
For more information on this dataset's structure, see
http://www.nitrc.org/projects/cluster_roi/

Craddock, R. Cameron, G.Andrew James, Paul E. Holtzheimer, Xiaoping P. Hu,
and Helen S. Mayberg. "A Whole Brain fMRI Atlas Generated via Spatially
Constrained Spectral Clustering". Human Brain Mapping 33, no 8 (2012):
1914–1928. doi:10.1002/hbm.21333.

Licence: Creative Commons Attribution Non-commercial Share Alike.